@@ -13,7 +13,6 @@ trees <- lapply(sample(10:500,50), function(x)tree <- rtree(x, rooted=FALSE) )
 #Descendants(x, node, type=c("tips","children","all"))
 #Siblings(tree, 3)
 #mrca.phylo(tree, 1:3)
-#midpoint
 
 
 desc_108 <- Descendants(tree, 108)[[1]]
@@ -25,15 +24,17 @@ test_that("ancestor, mrca, descendants", {
     expect_equal(mrca(tree), mrca.phylo(tree))
     kids_108 <- Descendants(tree, 108, "children")
     expect_equal(length(Descendants(tree, 101L, "all")), 197L)
-    expect_equal(lengths(Descendants(tree2, 101L:199, "all")), 2 * lengths(prop.part(tree2)) - 2L)
-    expect_equal(Ancestors(tree, kids_108, "parent"), rep(108L, length(kids_108)))
+    expect_equal(lengths(Descendants(tree2, 101L:199, "all")),
+                 2 * lengths(prop.part(tree2)) - 2L)
+    expect_equal(Ancestors(tree, kids_108, "parent"),
+                 rep(108L, length(kids_108)))
     expect_equal(Siblings(tree, kids_108[1], include.self=TRUE), kids_108)
 })
 
 test_that("allTrees", {
-    ## allTrees
-    expect_is(allTrees(6), "multiPhylo")
-    expect_true(all(RF.dist(allTrees(6))>0))
+  ## allTrees
+  expect_s3_class(allTrees(6), "multiPhylo")
+  expect_true(all(RF.dist(allTrees(6))>0))
 })
 
 
@@ -41,17 +42,21 @@ test_that("allTrees", {
 # TODO: check why rooted trees give error in development version
 test_that("midpoint", {
     # topology stays the same
-    expect_equal( max( sapply(trees, function(x)RF.dist(x,midpoint(x)))), 0) 
-    # 2 * max(height) == max(cophenetic) 
-    expect_equal( max( node.depth.edgelength(midpoint(tree)) *2) ,  max(cophenetic(tree)))              
-})    
-    
+    expect_equal( max( sapply(trees, function(x)RF.dist(x,midpoint(x)))), 0)
+    # 2 * max(height) == max(cophenetic)
+    expect_equal( max( node.depth.edgelength(midpoint(tree)) *2),
+                  max(cophenetic(tree)))
+})
+
 
 
 test_that("maxCladeCred", {
   tree <- rcoal(100)
   trees <- nni(tree)
   expect_equal(maxCladeCred(c(tree, trees)), tree)
+  tree <- rtree(100, rooted = FALSE)
+  trees <- nni(tree)
+  expect_equal(tree, allCompat(trees), use.edge.length = FALSE)
 })
 
 
